@@ -87,13 +87,16 @@ def list_bucket(s3client, samples_bucket, samples_path) -> list[str]:
     return member_list
 
 
-def get_samples(s3client, member_id, samples_bucket, samples_path) -> list:
+def get_samples(
+    s3client, member_id, samples_bucket, samples_path, verbose=False
+) -> list:
     """
     Retrieves the list of samples from the S3 bucket
     :param s3client: the s3client object to use to fetch
     :param samples_bucket: the name of the samples bucket
     :param samples_path: the path of the samples object
     :param member_id: the ID of the member to retrieve
+    :param verbose: whether to log progress
     :return: a list of samples
     """
 
@@ -110,7 +113,10 @@ def get_samples(s3client, member_id, samples_bucket, samples_path) -> list:
 
     with StringIO(data) as json_file:
         output = list(json_file)
-        logging.info(f"Found {len(output)} samples for " f"member {member_id}")
+        if verbose:
+            logging.info(
+                f"Found {len(output)} samples for " f"member {member_id}"
+            )
         return output
 
 
@@ -242,7 +248,9 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                 preservation_statuses, doi = preservation_status(result)
 
                 md5_doi = hashlib.md5(doi["DOI"].lower().encode())
-                key = f"{ANNOTATION_PATH}/works/{md5_doi}/{ANNOTATION_FILENAME}"
+                aws_key = (
+                    f"{ANNOTATION_PATH}/works/{md5_doi}/{ANNOTATION_FILENAME}"
+                )
 
                 preserved_json = {}
 
@@ -277,7 +285,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                     s3=s3,
                     json_obj=preserved_json,
                     bucket=ANNOTATION_BUCKET,
-                    path=key,
+                    path=aws_key,
                 )
 
                 # preserved_count refers to the number of works with at
